AttributeChange

Enum AttributeChange 

pub enum AttributeChange {
    Intensity(Intensity),
    Underline(Underline),
    Italic(bool),
    Blink(Blink),
    Reverse(bool),
    StrikeThrough(bool),
    Invisible(bool),
    Foreground(ColorAttribute),
    Background(ColorAttribute),
    Hyperlink(Option<Arc<Hyperlink>>),
}
Models a change in the attributes of a cell in a stream of changes. Each variant specifies one of the possible attributes; the corresponding value holds the new value to be used for that attribute.

Variants



Intensity(Intensity)



Underline(Underline)



Italic(bool)



Reverse(bool)



StrikeThrough(bool)



Invisible(bool)



Foreground(ColorAttribute)



Background(ColorAttribute)

Implementations

Source

impl AttributeChange

pub fn variants() -> &'static [&'static str]